<h1><a href="{{ concept_id }}"> {{ concept_preflabel }}</a></h1>

<h2>Inbound Links</h2>
<ul>
{% for s, p, o in inbound %}
    <li><a href="{{ s }}">{{ s }}</a>
        <a href="{{ p }}">{{ p.removeprefix("http://www.w3.org/2004/02/skos/core#") }}</a>
        <em>this</em></li>
{% endfor %}
</ul>

<h2>Outbound Links</h2>
<ul>
{% for s, p, o in outbound %}
    {% if p.endswith("Label") %}
     <li>
         <a href="{{ p }}">{{ p.removeprefix("http://www.w3.org/2004/02/skos/core#") }}</a>
         "{{ o }}"
     </li>
    {% else %}
    <li><a href="{{ p }}">{{ p.removeprefix("http://www.w3.org/2004/02/skos/core#") }}</a>
        <a href="{{ o }}">{{ o }}</a>
    </li>
    {% endif %}
{% endfor %}
</ul>